@@ -27,7 +27,6 @@
 #include <gtk/gtk.h>
 #include <packagekit-glib2/packagekit.h>
 
-#include "gs-cleanup.h"
 #include "gs-dbus-helper.h"
 #include "gs-packagekit-generated.h"
 #include "gs-packagekit-modify2-generated.h"
@@ -44,10 +43,6 @@ struct _GsDbusHelper {
 	guint			 dbus_own_name_id;
 };
 
-struct _GsDbusHelperClass {
-	GObjectClass	 parent_class;
-};
-
 G_DEFINE_TYPE (GsDbusHelper, gs_dbus_helper, G_TYPE_OBJECT)
 
 typedef struct {
@@ -80,7 +75,7 @@ static void
 gs_dbus_helper_task_set_interaction (GsDbusHelperTask *dtask, const gchar *interaction)
 {
 	guint i;
-	_cleanup_strv_free_ gchar **interactions = NULL;
+	g_auto(GStrv) interactions = NULL;
 
 	interactions = g_strsplit (interaction, ",", -1);
 	for (i = 0; interactions[i] != NULL; i++) {
@@ -127,10 +122,10 @@ gs_dbus_helper_query_is_installed_cb (GObject *source, GAsyncResult *res, gpoint
 {
 	GsDbusHelperTask *dtask = (GsDbusHelperTask *) data;
 	PkClient *client = PK_CLIENT (source);
-	_cleanup_error_free_ GError *error = NULL;
-	_cleanup_object_unref_ PkError *error_code = NULL;
-	_cleanup_object_unref_ PkResults *results = NULL;
-	_cleanup_ptrarray_unref_ GPtrArray *array = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(PkError) error_code = NULL;
+	g_autoptr(PkResults) results = NULL;
+	g_autoptr(GPtrArray) array = NULL;
 
 	/* get the results */
 	results = pk_client_generic_finish (client, res, &error);
@@ -169,14 +164,14 @@ out:
 static void
 gs_dbus_helper_query_search_file_cb (GObject *source, GAsyncResult *res, gpointer data)
 {
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 	GsDbusHelperTask *dtask = (GsDbusHelperTask *) data;
 	PkClient *client = PK_CLIENT (source);
 	PkInfoEnum info;
 	PkPackage *item;
-	_cleanup_ptrarray_unref_ GPtrArray *array = NULL;
-	_cleanup_object_unref_ PkError *error_code = NULL;
-	_cleanup_object_unref_ PkResults *results = NULL;
+	g_autoptr(GPtrArray) array = NULL;
+	g_autoptr(PkError) error_code = NULL;
+	g_autoptr(PkResults) results = NULL;
 
 	/* get the results */
 	results = pk_client_generic_finish (client, res, &error);
@@ -229,7 +224,7 @@ handle_query_search_file (GsPackageKitQuery	 *skeleton,
 {
 	GsDbusHelper *dbus_helper = user_data;
 	GsDbusHelperTask *dtask;
-	_cleanup_strv_free_ gchar **names = NULL;
+	g_auto(GStrv) names = NULL;
 
 	g_debug ("****** SearchFile");
 
@@ -256,7 +251,7 @@ handle_query_is_installed (GsPackageKitQuery	 *skeleton,
 {
 	GsDbusHelper *dbus_helper = user_data;
 	GsDbusHelperTask *dtask;
-	_cleanup_strv_free_ gchar **names = NULL;
+	g_auto(GStrv) names = NULL;
 
 	g_debug ("****** IsInstalled");
 
@@ -297,9 +292,9 @@ notify_search_resources (GsShellExtrasMode   mode,
 	const gchar *app_name = NULL;
 	const gchar *mode_string;
 	const gchar *title = NULL;
-	_cleanup_free_ gchar *body = NULL;
-	_cleanup_object_unref_ GDesktopAppInfo *app_info = NULL;
-	_cleanup_object_unref_ GNotification *n = NULL;
+	g_autofree gchar *body = NULL;
+	g_autoptr(GDesktopAppInfo) app_info = NULL;
+	g_autoptr(GNotification) n = NULL;
 
 	if (desktop_id != NULL) {
 		app_info = g_desktop_app_info_new (desktop_id);
@@ -684,9 +679,9 @@ bus_gotten_cb (GObject      *source_object,
                gpointer      user_data)
 {
 	GsDbusHelper *dbus_helper = GS_DBUS_HELPER (user_data);
-	_cleanup_object_unref_ GDBusConnection *connection = NULL;
-	_cleanup_object_unref_ GDesktopAppInfo *app_info = NULL;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GDBusConnection) connection = NULL;
+	g_autoptr(GDesktopAppInfo) app_info = NULL;
+	g_autoptr(GError) error = NULL;
 
 	connection = g_bus_get_finish (res, &error);
 	if (connection == NULL) {
