@@ -23,7 +23,6 @@
 
 #include <glib/gi18n.h>
 
-#include "gs-cleanup.h"
 #include "gs-shell.h"
 #include "gs-shell-overview.h"
 #include "gs-app.h"
@@ -35,7 +34,7 @@
 
 #define N_TILES 6
 
-struct GsShellOverviewPrivate
+typedef struct
 {
 	GsPluginLoader		*plugin_loader;
 	GtkBuilder		*builder;
@@ -61,7 +60,7 @@ struct GsShellOverviewPrivate
 	GtkWidget		*popular_rotating_heading;
 	GtkWidget		*scrolledwindow_overview;
 	GtkWidget		*stack_overview;
-};
+} GsShellOverviewPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsShellOverview, gs_shell_overview, GS_TYPE_PAGE)
 
@@ -74,7 +73,7 @@ static guint signals [SIGNAL_LAST] = { 0 };
 
 typedef struct {
         GsCategory	*category;
-        GsShellOverview	*shell_overview;
+        GsShellOverview	*self;
 } LoadData;
 
 static void
@@ -82,8 +81,8 @@ load_data_free (LoadData *data)
 {
         if (data->category != NULL)
                 g_object_unref (data->category);
-        if (data->shell_overview != NULL)
-                g_object_unref (data->shell_overview);
+        if (data->self != NULL)
+                g_object_unref (data->self);
         g_slice_free (LoadData, data);
 }
 
@@ -91,19 +90,22 @@ load_data_free (LoadData *data)
  * gs_shell_overview_invalidate:
  **/
 void
-gs_shell_overview_invalidate (GsShellOverview *shell_overview)
+gs_shell_overview_invalidate (GsShellOverview *self)
 {
-	shell_overview->priv->cache_valid = FALSE;
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
+
+	priv->cache_valid = FALSE;
 }
 
 static void
 popular_tile_clicked (GsPopularTile *tile, gpointer data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (data);
+	GsShellOverview *self = GS_SHELL_OVERVIEW (data);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsApp *app;
 
 	app = gs_popular_tile_get_app (tile);
-	gs_shell_show_app (shell->priv->shell, app);
+	gs_shell_show_app (priv->shell, app);
 }
 
 static gboolean
@@ -122,15 +124,15 @@ gs_shell_overview_get_popular_cb (GObject *source_object,
 				  GAsyncResult *res,
 				  gpointer user_data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (user_data);
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverview *self = GS_SHELL_OVERVIEW (user_data);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	GList *l;
-	GList *list;
 	GsApp *app;
 	gint i;
 	GtkWidget *tile;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GsAppList) list = NULL;
 
 	/* get popular apps */
 	list = gs_plugin_loader_get_popular_finish (plugin_loader, res, &error);
@@ -151,19 +153,18 @@ gs_shell_overview_get_popular_cb (GObject *source_object,
 		app = GS_APP (l->data);
 		tile = gs_popular_tile_new (app);
 		g_signal_connect (tile, "clicked",
-			  G_CALLBACK (popular_tile_clicked), shell);
+			  G_CALLBACK (popular_tile_clicked), self);
 		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
 
 	priv->empty = FALSE;
 
 out:
-	gs_plugin_list_free (list);
 	priv->loading_popular = FALSE;
 	priv->refresh_count--;
 	if (priv->refresh_count == 0) {
 		priv->cache_valid = TRUE;
-		g_signal_emit (shell, signals[SIGNAL_REFRESHED], 0);
+		g_signal_emit (self, signals[SIGNAL_REFRESHED], 0);
 	}
 }
 
@@ -173,15 +174,15 @@ gs_shell_overview_get_popular_rotating_cb (GObject *source_object,
 					   gpointer user_data)
 {
 	LoadData *load_data = (LoadData *) user_data;
-	GsShellOverview *shell = load_data->shell_overview;
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverview *self = load_data->self;
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	GList *l;
-	GList *list;
 	GsApp *app;
 	gint i;
 	GtkWidget *tile;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GsAppList) list = NULL;
 
 	/* get popular apps */
 	list = gs_plugin_loader_get_category_apps_finish (plugin_loader, res, &error);
@@ -208,31 +209,31 @@ gs_shell_overview_get_popular_rotating_cb (GObject *source_object,
 		app = GS_APP (l->data);
 		tile = gs_popular_tile_new (app);
 		g_signal_connect (tile, "clicked",
-			  G_CALLBACK (popular_tile_clicked), shell);
+			  G_CALLBACK (popular_tile_clicked), self);
 		gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), tile);
 	}
 
 	priv->empty = FALSE;
 
 out:
-	gs_plugin_list_free (list);
 	load_data_free (load_data);
 	priv->loading_popular_rotating = FALSE;
 	priv->refresh_count--;
 	if (priv->refresh_count == 0) {
 		priv->cache_valid = TRUE;
-		g_signal_emit (shell, signals[SIGNAL_REFRESHED], 0);
+		g_signal_emit (self, signals[SIGNAL_REFRESHED], 0);
 	}
 }
 
 static void
 feature_tile_clicked (GsFeatureTile *tile, gpointer data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (data);
+	GsShellOverview *self = GS_SHELL_OVERVIEW (data);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsApp *app;
 
 	app = gs_feature_tile_get_app (tile);
-	gs_shell_show_app (shell->priv->shell, app);
+	gs_shell_show_app (priv->shell, app);
 }
 
 static void
@@ -240,13 +241,13 @@ gs_shell_overview_get_featured_cb (GObject *source_object,
 				   GAsyncResult *res,
 				   gpointer user_data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (user_data);
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverview *self = GS_SHELL_OVERVIEW (user_data);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	GtkWidget *tile;
-	GList *list;
 	GsApp *app;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GsAppList) list = NULL;
 
 	list = gs_plugin_loader_get_featured_finish (plugin_loader, res, &error);
 	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
@@ -269,30 +270,30 @@ gs_shell_overview_get_featured_cb (GObject *source_object,
 	app = GS_APP (list->data);
 	tile = gs_feature_tile_new (app);
 	g_signal_connect (tile, "clicked",
-			  G_CALLBACK (feature_tile_clicked), shell);
+			  G_CALLBACK (feature_tile_clicked), self);
 
 	gtk_container_add (GTK_CONTAINER (priv->bin_featured), tile);
 
 	priv->empty = FALSE;
 
 out:
-	gs_plugin_list_free (list);
 	priv->loading_featured = FALSE;
 	priv->refresh_count--;
 	if (priv->refresh_count == 0) {
 		priv->cache_valid = TRUE;
-		g_signal_emit (shell, signals[SIGNAL_REFRESHED], 0);
+		g_signal_emit (self, signals[SIGNAL_REFRESHED], 0);
 	}
 }
 
 static void
 category_tile_clicked (GsCategoryTile *tile, gpointer data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (data);
+	GsShellOverview *self = GS_SHELL_OVERVIEW (data);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsCategory *category;
 
 	category = gs_category_tile_get_category (tile);
-	gs_shell_show_category (shell->priv->shell, category);
+	gs_shell_show_category (priv->shell, category);
 }
 
 /**
@@ -303,16 +304,16 @@ gs_shell_overview_get_categories_cb (GObject *source_object,
 				     GAsyncResult *res,
 				     gpointer user_data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (user_data);
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverview *self = GS_SHELL_OVERVIEW (user_data);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	gint i;
 	GList *l;
-	GList *list;
 	GsCategory *cat;
 	GtkWidget *tile;
 	gboolean has_category = FALSE;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GsAppList) list = NULL;
 
 	list = gs_plugin_loader_get_categories_finish (plugin_loader, res, &error);
 	if (list == NULL) {
@@ -328,13 +329,12 @@ gs_shell_overview_get_categories_cb (GObject *source_object,
 			continue;
 		tile = gs_category_tile_new (cat);
 		g_signal_connect (tile, "clicked",
-				  G_CALLBACK (category_tile_clicked), shell);
+				  G_CALLBACK (category_tile_clicked), self);
 		gtk_grid_attach (GTK_GRID (priv->grid_categories), tile, i % 4, i / 4, 1, 1);
 		i++;
 		has_category = TRUE;
 	}
 out:
-	gs_plugin_list_free (list);
 	if (has_category) {
 		priv->empty = FALSE;
 	}
@@ -344,7 +344,7 @@ out:
 	priv->refresh_count--;
 	if (priv->refresh_count == 0) {
 		priv->cache_valid = TRUE;
-		g_signal_emit (shell, signals[SIGNAL_REFRESHED], 0);
+		g_signal_emit (self, signals[SIGNAL_REFRESHED], 0);
 	}
 }
 
@@ -352,11 +352,11 @@ out:
  * gs_shell_overview_load:
  */
 static void
-gs_shell_overview_load (GsShellOverview *shell_overview)
+gs_shell_overview_load (GsShellOverview *self)
 {
-	GsShellOverviewPrivate *priv = shell_overview->priv;
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	const gchar *category_of_day;
-	_cleanup_date_time_unref_ GDateTime *date = NULL;
+	g_autoptr(GDateTime) date = NULL;
 
 	priv->empty = TRUE;
 
@@ -395,7 +395,7 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
 						     GS_PLUGIN_REFINE_FLAGS_DEFAULT,
 						     priv->cancellable,
 						     gs_shell_overview_get_featured_cb,
-						     shell_overview);
+						     self);
 		priv->refresh_count++;
 	}
 
@@ -405,21 +405,21 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
 						    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
 						    priv->cancellable,
 						    gs_shell_overview_get_popular_cb,
-						    shell_overview);
+						    self);
 		priv->refresh_count++;
 	}
 
 	if (!priv->loading_popular_rotating) {
 		LoadData *load_data;
-		_cleanup_object_unref_ GsCategory *category = NULL;
-		_cleanup_object_unref_ GsCategory *featured_category = NULL;
+		g_autoptr(GsCategory) category = NULL;
+		g_autoptr(GsCategory) featured_category = NULL;
 
 		category = gs_category_new (NULL, category_of_day, NULL);
 		featured_category = gs_category_new (category, "featured", NULL);
 
 		load_data = g_slice_new0 (LoadData);
 		load_data->category = g_object_ref (category);
-		load_data->shell_overview = g_object_ref (shell_overview);
+		load_data->self = g_object_ref (self);
 
 		priv->loading_popular_rotating = TRUE;
 		gs_plugin_loader_get_category_apps_async (priv->plugin_loader,
@@ -437,7 +437,7 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
 						       GS_PLUGIN_REFINE_FLAGS_DEFAULT,
 						       priv->cancellable,
 						       gs_shell_overview_get_categories_cb,
-						       shell_overview);
+						       self);
 		priv->refresh_count++;
 	}
 }
@@ -446,19 +446,19 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
  * gs_shell_overview_reload:
  */
 void
-gs_shell_overview_reload (GsShellOverview *shell_overview)
+gs_shell_overview_reload (GsShellOverview *self)
 {
-	gs_shell_overview_invalidate (shell_overview);
-	gs_shell_overview_load (shell_overview);
+	gs_shell_overview_invalidate (self);
+	gs_shell_overview_load (self);
 }
 
 /**
  * gs_shell_overview_switch_to:
  **/
 void
-gs_shell_overview_switch_to (GsShellOverview *shell, gboolean scroll_up)
+gs_shell_overview_switch_to (GsShellOverview *self, gboolean scroll_up)
 {
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GtkWidget *widget;
 	GtkAdjustment *adj;
 
@@ -484,22 +484,22 @@ gs_shell_overview_switch_to (GsShellOverview *shell, gboolean scroll_up)
 
 	if (priv->cache_valid || priv->refresh_count > 0)
 		return;
-	gs_shell_overview_load (shell);
+	gs_shell_overview_load (self);
 }
 
 void
-gs_shell_overview_setup (GsShellOverview *shell_overview,
+gs_shell_overview_setup (GsShellOverview *self,
 			 GsShell *shell,
 			 GsPluginLoader *plugin_loader,
 			 GtkBuilder *builder,
 			 GCancellable *cancellable)
 {
-	GsShellOverviewPrivate *priv = shell_overview->priv;
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 	GtkAdjustment *adj;
 	GtkWidget *tile;
 	gint i;
 
-	g_return_if_fail (GS_IS_SHELL_OVERVIEW (shell_overview));
+	g_return_if_fail (GS_IS_SHELL_OVERVIEW (self));
 
 	priv->plugin_loader = g_object_ref (plugin_loader);
 	priv->builder = g_object_ref (builder);
@@ -523,25 +523,23 @@ gs_shell_overview_setup (GsShellOverview *shell_overview,
 	}
 
 	/* chain up */
-	gs_page_setup (GS_PAGE (shell_overview),
+	gs_page_setup (GS_PAGE (self),
 	               shell,
 	               plugin_loader,
 	               cancellable);
 }
 
 static void
-gs_shell_overview_init (GsShellOverview *shell)
+gs_shell_overview_init (GsShellOverview *self)
 {
-	gtk_widget_init_template (GTK_WIDGET (shell));
-
-	shell->priv = gs_shell_overview_get_instance_private (shell);
+	gtk_widget_init_template (GTK_WIDGET (self));
 }
 
 static void
 gs_shell_overview_dispose (GObject *object)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (object);
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverview *self = GS_SHELL_OVERVIEW (object);
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 
 	g_clear_object (&priv->builder);
 	g_clear_object (&priv->plugin_loader);
@@ -552,9 +550,9 @@ gs_shell_overview_dispose (GObject *object)
 }
 
 static void
-gs_shell_overview_refreshed (GsShellOverview *shell)
+gs_shell_overview_refreshed (GsShellOverview *self)
 {
-	GsShellOverviewPrivate *priv = shell->priv;
+	GsShellOverviewPrivate *priv = gs_shell_overview_get_instance_private (self);
 
 	if (priv->empty) {
 		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack_overview), "no-results");
