@@ -24,7 +24,6 @@
 #include <gs-plugin.h>
 #include <glib/gi18n.h>
 
-#include "gs-cleanup.h"
 #include "menu-spec-common.h"
 
 /**
@@ -61,7 +60,7 @@ gs_plugin_add_categories (GsPlugin *plugin,
 			*list = g_list_prepend (*list, category);
 			g_snprintf(msgctxt, 100, "Menu subcategory of %s", msdata[i].text);
 		} else {
-			_cleanup_object_unref_ GsCategory *sub = NULL;
+			g_autoptr(GsCategory) sub = NULL;
 			sub = gs_category_new (category,
 					       tmp + 2,
 					       g_dpgettext2(GETTEXT_PACKAGE, msgctxt, msdata[i].text));
